## ----echo=FALSE, message=FALSE-------------------------------------------
library(BALD)
library(knitr)

## ----simB, echo=TRUE, eval=TRUE------------------------------------------
set.seed(2)
blockSizes <- c(2,4,5,3,2,4)
p <- sum(blockSizes)
sig.blocks <- c(3,5)
nb.per.block <- c(2,3)
betas <- simBeta(blockSizes, sig.blocks, nb.per.block)

## ----betaBS, echo=TRUE---------------------------------------------------
betas$blockSizes

## ----betasnp, echo=TRUE--------------------------------------------------
str(betas$betaMat)

## ----betabl, echo=TRUE---------------------------------------------------
betas$betaMat[,"betaBl"]

## ----sim, echo=TRUE, eval=TRUE-------------------------------------------
N <- 50
corr <- 0.5
r2 <- 0.7
sim <- simulation(N, betas$betaMat[, "betaSNP"], betas$blockSizes, 
                  corr, r2)
X <- sim$X
str(X)
y <- sim$y
str(y)
sim$r2  ## effective coefficient of determination

## ----tsm, echo=TRUE, eval=TRUE, tidy=FALSE-------------------------------
nlambda <- 30
B <- 50
## assessing the within-cluster measures for the B reference datasets
traceWB <- lapply(1:B, FUN=function(ii){
  getTraceW(N, p)
})
traceWB <- simplify2array(traceWB)
gl <- grplassoCWard(sim$X, sim$y, groups=NULL, nlambda=nlambda, 
                    max.nc=p-1, min.nc=1, traceWB=traceWB)
str(gl)

## ----grps, echo=TRUE, eval=TRUE------------------------------------------
betas$blockSizes
gl$groups
tab <- table(gl$groups)
dimnames(tab) <- NULL
tab

## ----methods, echo=TRUE, eval=FALSE, tidy=FALSE--------------------------
#  coefsGL <- select("groupLasso", X, y, groups=NULL,  nlambda=nlambda,
#                    max.nc=p-1, min.nc=2, B=100)
#  coefsOGL <- select("groupLasso", X, y, groups=betas$groups,
#                     nlambda=nlambda)   ## Oracle Group Lasso !
#  coefsL <- select("lasso", X, y, nlambda=nlambda)
#  coefsEN <- select("elastic.net", X, y, lambda2=0.5, nlambda=nlambda)
#  pvalsUniv <- select("univ", X, y, nlambda=nlambda)

## ----eval=FALSE----------------------------------------------------------
#  system.file("evaluation/evaluation.Rnw", package="BALD")

## ----echo=TRUE, eval=TRUE, tidy=FALSE------------------------------------
## "true" beta
betas$betaMat[,"betaSNP"]

groups <- gl$groups
coefsGL <- select("groupLasso", X, y, groups=groups,  nlambda=nlambda)
selSNP <- as.matrix(t(coefsGL)!=0)

## blocks selected by GL at each level of regularization 
selBl <- as.matrix(aggregate(selSNP, list(groups=groups), sum)[, -1])
str(selBl)
selBl[,1:3]
## first 3 blocks selected by GL
firstBl <- which(selBl[,2]!=0)

## first 5 SNPs selected by the Lasso
coefsL <- select("lasso", X, y, nlambda=nlambda)
firstSNPs <- which(coefsL[4,]!=0)

## heatmap plot
blockSizes <- betas$blockSizes

## ----plotCode, tidy=FALSE, echo=TRUE, eval=FALSE-------------------------
#  plotHeatmap(X, blockSizes, selBlocks=firstBl, snpNames=as.character(1:p),
#              snpStar=as.character(firstSNPs))

## ----ref.label='plotCode', dev='pdf', fig.keep='last', fig.pos='!h', echo=FALSE----
plotHeatmap(X, blockSizes, selBlocks=firstBl, snpNames=as.character(1:p), 
            snpStar=as.character(firstSNPs))

## ----plot2, echo=TRUE, eval=TRUE, fig.keep='last', tidy=FALSE, fig.pos='!'----
## univariate p-values
pvals <- apply(X, 2, FUN=function(vect){
  pv <- summary(lm(y ~ vect))$coefficients[2,4]
})

## first 3 blocks displayed
plotGroupsGL(coefsGL, nbGroup=3, pvals)

## ----sessionInfo---------------------------------------------------------
sessionInfo()

