\name{evalRoc}
\alias{evalRoc}
\title{evalRoc}
\description{Returns, as an array, the ROC coordinates of a set of methods given the regression coefficients of these methods and the 'true' (simulated) coefficients.}
\usage{evalRoc(estBetas, trueBetas, aggregate = TRUE)}
\arguments{
  \item{estBetas}{numeric array with 4 dimensions containing the estimated regression coefficients. The first 2 dimensions correspond to the regularization parameter and the number of variables. The last 2 dimensions correspond to the regression method and the simulation run and must be called respectively "methods" and "simulation".}
  \item{trueBetas}{(number of variables) x (number of simulations) matrix containing the reference regression coefficients. }
  \item{aggregate}{logical. Indicates if the ROC coordinates returned should be aggregated over the simulation runs.}
}

\value{A numeric array containing the 3 dimensions: "ROC" (ROC coordinates), "grid" (regularization parameter grid) and "methods" (regression methods names). If aggregate=FALSE, the 4th dimension "simulation" is kept.}

\author{Alia Dehman, Christophe Ambroise and Pierre Neuvial}



\seealso{\code{\link{coordROC}}.}
\examples{
nb.simu <- 5

set.seed(5)
blockSizes <- sample(2:5, 8, replace=TRUE)
p <- sum(blockSizes)
sig.blocks <- 2
nb.per.block <- 1
BS <- replicate(nb.simu, simBeta(blockSizes, sig.blocks, 
                                 nb.per.block), simplify=FALSE)
N <- 10
corr <- 0.5
r2 <- 0.7
datList <- lapply(BS, FUN=function(x) {
  betaSNP <- x$betaMat[, "betaSNP"]
  simulation(N, betaSNP, x$blockSizes, corr, r2)
})
trueBetaSNP <- sapply(BS, function(simb) {simb$betaMat[, "betaSNP"]})
nlambda <- 10
dimnames <- list(
                 grid=seq(length=nlambda),
                 predictor=1:p,
                 methods=c("GL", "lasso"),
                 simulation=seq(length=nb.simu))
dims <- sapply(dimnames, length)
coefs <- array(NA, dim=dims, dimnames=dimnames)

for (jj in 1:nb.simu){
  datJJ <- datList[[jj]]
  X <- datJJ$X
  stopifnot(ncol(X)==p)
  y <- datJJ$y
  blockSizes <- BS[[jj]]$blockSizes
  nBlocks <- length(blockSizes)
  groups <- rep(1:nBlocks, times=blockSizes)
  coefs[,, "GL", jj] <- select("groupLasso", X, y, nlambda=nlambda, groups=groups)
  coefs[,, "lasso", jj] <- select("lasso", X, y, nlambda=nlambda)
}
roc <- evalRoc(coefs, trueBetaSNP)
str(roc)
}
