\name{grplassoCWard}
\alias{grplassoCWard}
\title{grplassoCWard}
\description{Fits the solution of a Group Lasso problem. If the groups are not given, infers the group structure using a constrained hierarchical clustering and then estimates the number of clusters using the Gap statistic method.}
\usage{grplassoCWard(X, y, nlambda = 100, groups = NULL, ...)}
\arguments{
  \item{X}{genotype matrix coded in {1, 2, 3}. Variables in columns.}
  \item{y}{phenotype vector.}
  \item{nlambda}{length of the vector of penalty level. Defaults to 100.}
  \item{groups}{vector which defines the grouping of the variables. Components sharing the same number build a group. Non-penalized coefficients are marked with NA. If NULL (default), the groups are assessed using the function \code{gapStatistic}.}
  \item{\dots}{optionally further arguments for the function \code{\link{gapStatistic}}.  }
}

\value{A list with elements
\item{coefs}{\code{nlambda x p} matrix of the Group Lasso coefficients.}
\item{groups}{provided/estimated groups.
}}
\references{J. H. Ward Jr. Hierarchical grouping to optimize an objective function. Journal of the American statistical association, 58(301):236-244, 1963.}
\author{Alia Dehman, Christophe Ambroise and Pierre Neuvial}



\seealso{\code{\link{gapStatistic}}, \code{\link{cWard}}, \code{\link{select}}.}
\examples{

set.seed(5)
## Structured data: 3 clusters
N <- 30
r2 <- 0.2
corr <- 0.6
blockSizes <- c(3:5)
p <- sum(blockSizes)
nBlocks <- length(blockSizes)
sig.blocks <- 5
nb.per.block <- 1
betas <- simBeta(blockSizes, sig.blocks, nb.per.block)
sim <- simulation(N, betas$betaMat[,"betaSNP"], betas$blockSizes, corr, r2, minMAF=0.45)
X <- sim$X
y <- sim$y
groups <- betas$betaMat[,"groups"]   ## effective groups: betas$blockSizes !!
## Oracle Group Lasso: with "true" groups
OGL <- grplassoCWard(X, y, groups=groups)
identical(OGL$groups, groups)    ## same groups vector retrieved
## Group Lasso with estimated groups
## we use B=50 to keep it fast..
B <- 50
traceWB <- lapply(1:B, FUN=function(ii){
  getTraceW(N, p)
})
traceWB <- simplify2array(traceWB)
OGE <- grplassoCWard(X, y, groups=NULL, min.nc=1, max.nc=p-1, traceWB=traceWB)
identical(OGE$groups, groups)   ## groups well estimated !

}
