\name{plotGroupsGL}
\alias{plotGroupsGL}
\title{significance plot of LD blocks}
\description{This function provides a graphical display for interpreting selected groups in function of univariate p-values of the SNPs contained in these blocks. }
\usage{plotGroupsGL(coefsGL, nbGroup, pvals, meth = "BH", t = 0.25)}
\arguments{
  \item{coefsGL}{should be an output of the function select with method="groupLasso" : real matrix of the regression coefficients of the Group Lasso with an attribute \code{"groups"} describing the group structure of the variables. See \code{\link{select}}. }
  \item{nbGroup}{integer. Indicates the number of groups to be plotted. Must be less or equal to the total number of groups.}
  \item{pvals}{numeric vector. Univariate p-values of the variables. Must be the same length as \code{ncol(coefsGL)}.}
  \item{meth}{adjustment method for univariate \code{p}-values. See \code{\link[stats]{p.adjust}}.}
  \item{t}{significance threshold. }
}

\value{The graphical display returned contains, in the background, the histogram of the distribution of the (-log10-transformed) univariate p-values. It also represents each of the first \code{nbGroup} selected groups by a colored horizontal segment ranging from the smallest to the largest univariate p-value of the block. Vertical black segments indicate univariate p-values of each variable in these group and a vertical line highlights the significance threshold chosen.}

\author{Alia Dehman, Christophe Ambroise and Pierre Neuvial}



\seealso{\code{\link{select}}, \code{\link{grplassoCWard}}, \code{\link[stats]{p.adjust}}}
\examples{
set.seed(0.2)
## Structured data: 7 clusters
N <- 100
p <- 30
r2 <- 0.5
corr <- 0.8
blockSizes <- c(2:7, 3)
sig.blocks <- c(3,5,7)
nb.per.block <- 1
betas <- simBeta(blockSizes, sig.blocks, nb.per.block)
sim <- simulation(N, betas$betaMat[,"betaSNP"], betas$blockSizes, corr, r2, minMAF=0.45)
blockSizes <- betas$blockSizes  ## effective blockSizes used for simulation !
nBlocks <- length(blockSizes)
groups <- betas$betaMat[,"groups"]
coefsGL <- select("groupLasso", sim$X, sim$y, groups=groups)
## univariate p-values
pvals <- apply(sim$X, 2, FUN=function(vect){
  pv <- summary (lm(sim$y ~ vect))$coefficients[2,4]
})
plotGroupsGL(coefsGL, nbGroup=6, pvals)
## all the univariate p-values of the first selected 2 blocks are smaller than
## the 0.05 significance threshold !
}
