\name{plotHeatmap}
\alias{plotHeatmap}
\title{plotHeatmap}
\description{Heat map of LD blocks where SNPs/LD blocks are highlighted}
\usage{plotHeatmap(X, blockSizes, selBlocks = NULL, stats = "R.squared", 
    snpNames = NULL, snpStar = NULL)}
\arguments{
  \item{X}{genotype matrix coded in {1, 2, 3}. The SNPs to be plotted in columns.}
  \item{blockSizes}{a vector of integers specifying the sizes of the groups. The sum of the sizes must be equal to the length of \code{ncol(p)}. }
  \item{selBlocks}{a vector of integers specifying the indices of the blocks to be highlighted among \code{blockSizes}. Default \code{NULL}.}
  \item{stats}{a character specifying the LD measure to be used. This should contain one of these strings: \code{R.squared} or \code{D.prime}. Defaults to \code{R.squared}.}
  \item{snpNames}{character. Names of the SNPs to be plotted. Defaults to NULL.}
  \item{snpStar}{a vector of character. Names of the SNPs to be highlighted. Must be element of \code{snpNames}. Defaults to NULL.}
}
\details{The LD measures are calculated using the function \code{\link[snpStats]{ld}} which handles missing values of the genotype.}
\value{A heatmap plot of the LD blocks and optionally a highlight of blocks/SNPs.  }
\references{J.-H. Shin and S. Blay and B. McNeney and J. Graham. LDheatmap: An R Function for Graphical Display of Pairwise Linkage Disequilibria Between Single Nucleotide Polymorphisms. Journal of Statistical Software 16: Code Snippet 3.}
\author{Alia Dehman, Christophe Ambroise and Pierre Neuvial}



\seealso{\code{\link[snpStats]{ld}}, \code{\link[LDheatmap]{LDheatmap}}.}
\examples{
## Structured data: 7 clusters
N <- 100
p <- 30
r2 <- 0.2
corr <- 0.8
blockSizes <- c(2:7, 3)
sig.blocks <- 5
nb.per.block <- 1
betas <- simBeta(blockSizes, sig.blocks, nb.per.block)
sim <- simulation(N, betas$betaMat[,"betaSNP"], betas$blockSizes, corr, r2)
X <- sim$X
plotHeatmap(X, betas$blockSizes)
plotHeatmap(X, betas$blockSizes, stats="D.prime", snpNames=as.character(1:30),
            snpStar=as.character(c(1,3,15,20)))
}
