\name{select}
\alias{select}
\title{variable selection models}
\description{Fits the regression model for the methods Univariate, Lasso, Elastic-Net, Group Lasso.}
\usage{select(method = c("lasso", "elastic.net", "groupLasso", "univ"), 
    X, y, nlambda = 100, lambda2 = 0.8, ...)}
\arguments{
  \item{method}{regression model.}
  \item{X}{genotype matrix coded in {1, 2, 3}.}
  \item{y}{phenotype vector.}
  \item{nlambda}{length of the vector of \eqn{l_1-}penalty levels. Defaults to 100.}
  \item{lambda2}{numeric value. Tunes the \eqn{l_2-}penalty of the Elastic Net. Defaults to 0.8.}
  \item{\dots}{optionally further arguments for downstream selection methods.}
}

\value{
\item{coefs}{\code{nlambda x p} matrix of regression coefficients for penalized regression models (Group Lasso, Lasso and Elastic Net). Logical matrix for the univariate model where each row corresponds to a threshold p-value for selection. The group structure (known or estimated) is returned as an attribute.
}}
\references{R. Tibshirani. Regression shrinkage and selection via the lasso. Journal of the Royal Statistical Society. Series B (Methodological), pages 267-288, 1996.

H. Zou and T. Hastie. Regularization and variable selection via the elastic net. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 67(2):301-320, 2005.}
\author{Alia Dehman, Christophe Ambroise and Pierre Neuvial}



\seealso{\code{\link{grplassoCWard}}.}
\examples{

set.seed(5)
N <- 50
r2 <- 0.5
corr <- 0.5
blockSizes <- sample(3:5, 10, replace=TRUE)
p <- sum(blockSizes)
p
sig.blocks <- 4
nb.per.block <- 1
betas <- simBeta(blockSizes, sig.blocks, nb.per.block)
sim <- simulation(N, betas$betaMat[,"betaSNP"], betas$blockSizes, corr, r2, minMAF=0.45)
X <- sim$X
y <- sim$y
blockSizes <- betas$blockSizes  ## effective blockSizes used for simulation !
nBlocks <- length(blockSizes)
groups <- betas$betaMat[,"groups"]
coefsGL <- select("groupLasso", sim$X, sim$y, groups=groups)
head(blockSizes, 3)  ## sizes of the first 3 blocks
## simulated regression coefficients of the first 3 blocks
head(betas$betaMat[,"betaSNP"], sum(blockSizes[1:3]))   
head(betas$betaMat[,"betaBl"], sum(blockSizes[1:3]))  
which(coefsGL[2,]!=0)  ## indices of the first selected group
coefsL <- select("lasso", sim$X, sim$y, lambda2=0.5)
pvalsUniv <- select("univ", sim$X, sim$y)
which(pvalsUniv[2,]!=0) ## index of the first selected variable.

}
