\name{simBeta}
\alias{simBeta}
\title{regression vector generation}
\description{Given a set of group-structured variables, this function allows to simulate vector of coefficients related to each variable given the sizes of the non-null groups (groups containing at least one non-null coefficient) and the number of non-null variables within each group. This function allows also to simulate a logical "group-vector", that is all the variables contained in a non-null group are simulated as TRUE.}
\usage{simBeta(blockSizes, sig.blocks, nb.per.block, resample = TRUE)}
\arguments{
  \item{blockSizes}{vector of integers with the sizes of the groups.}
  \item{sig.blocks}{vector of integers. Sizes of the non-null groups. If two or more non-null groups have the same size, this value of the size should be replicated in sig.blocks. Should be a subset of \code{blockSizes}.}
  \item{nb.per.block}{integer or vector of integers. The number of non-null coefficients within each non-null group. If it is an integer, should be less or equal to min(\code{sig.blocks}). If it is a vector of integers, this latter should have the same length as \code{sig.blocks} and \code{resample} must be set to FALSE.}
  \item{resample}{logical. Indicates if the block sizes should be resampled or not.}
}

\value{A list with elements
\item{blockSizes}{a resampling of the original argument \code{blockSizes} used for the simulation of the coefficients,}
\item{betaMat}{\describe{\item{a \code{p x 3} matrix with columns}{
\itemize{
\item{\code{betaSNP}: }{the vector of coefficients. Non-null ones are randomly sampled among the values \{-1,1\}}
\item{\code{betaBl}: }{logical vector. TRUE is assigned to all the variables of the non-null groups.}
\item{\code{groups}: }{the vector which defines the grouping of the variables. Components sharing the same number build a group.}
}
}}
}}

\author{Alia Dehman, Christophe Ambroise and Pierre Neuvial}
\note{Non-null coefficients are placed at the first positions of the non-null group.}


\seealso{\code{\link{simulation}}.}
\examples{
set.seed(5)
blockSizes <- sample(2:5, 5, replace=TRUE)
sig.blocks <- c(2,3)
l <- length(sig.blocks)
if (sum(is.element(sig.blocks,blockSizes))!=l) stop("sig.blocks must be a subset of blockSizes !")
## one associated variable per group
nb.per.block <- 1
simb <- simBeta(blockSizes, sig.blocks, nb.per.block)
betaMat <- simb$betaMat
simb$blockSizes ## effective blockSizes used for the simulation !
betaSNP <- betaMat[, "betaSNP"]
betaSNP  ## the first group of the two of size 2 is considered as non-null. 

betaBl <- betaMat[, "betaBl"]
betaBl ## all the coefficients of the non-null group are non null.

## different number of associated variables per group
## nb.per.block should have the same length as sig.blocks !
nb.per.block <- c(1,2)
simb <- simBeta(blockSizes, sig.blocks, nb.per.block)
simb$blockSizes
simb$betaMat[,"betaSNP"]

}
