\name{simR2}
\alias{simR2}
\title{Calculation of the \eqn{r^2} linkage disequilibrium measure}
\description{This function returns the pairs of \eqn{r^2} LD measures between each column of \eqn{X[,i]} and each column of \eqn{X[,j]}. If i and j are not provided, this function returns a vector of the \eqn{p-1} \eqn{r^2} LD measures between the adjacent columns of X. }
\usage{simR2(X, i, j)}
\arguments{
  \item{X}{genotype matrix coded in {1, 2, 3} with the SNPs in columns.}
  \item{i}{(optional) vector of integers. Indices of the SNPs of the first group among the columns of X of length \eqn{l_1}. \eqn{l_1} must be between 1 and p.}
  \item{j}{(optional) vector of integers. Indices of the SNPs of the second group among the columns of X of length \eqn{l_2}. \eqn{l_2} must be between 1 and p.}
}

\value{If \code{i} and \code{j} are provided, a \code{l_1 x l_2} matrix of the \eqn{r^2} LD measures is returned. Else, a (p-1) vector of the \eqn{r^2} LD measures between the adjacent columns of X is returned.  }
\references{B. Devlin and N. Risch. A comparison of linkage disequilibrium measures for fine-scale mapping. Genomics, 29(2):311-322, 1995.}
\author{Alia Dehman, Christophe Ambroise and Pierre Neuvial}



\seealso{\code{\link{simDp}}, \code{\link{cWard}}.}
\examples{
N <- 100
p <- 20
X <- matrix(ceiling(runif(N*p)*3), N, p)
simR2(X, 1:5, 1:10)
simR2(X)
}
